import{k as d}from"./router.135b49e3.js";import"./jwt-decode.esm.b9bb33e7.js";(function(){try{var a=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(a._sentryDebugIds=a._sentryDebugIds||{},a._sentryDebugIds[e]="dda99b58-39dd-42d1-9db0-6037b19682cc",a._sentryDebugIdIdentifier="sentry-dbid-dda99b58-39dd-42d1-9db0-6037b19682cc")}catch{}})();class s{async list(e){return d.get(`organizations/${e}/folders`)}async create(e){return d.post(`organizations/${e.organizationId}/folders`,{name:e.name,memberIds:e.memberIds})}async checkNameAvailability(e,n){return d.post(`organizations/${e}/folders/name-available`,{folderName:n})}async delete(e,n){return d.delete(`organizations/${e}/folders/${n}`)}async update(e,n){return d.patch(`organizations/${e}/folders/${n.id}/`,{name:n.name,memberIds:n.memberIds})}}export{s as F};
//# sourceMappingURL=folder.c07afb46.js.map
