import{d as o,o as d,ac as s,e as l,ae as r,eh as t,_ as c}from"./jwt-decode.esm.b9bb33e7.js";(function(){try{var a=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(a._sentryDebugIds=a._sentryDebugIds||{},a._sentryDebugIds[e]="923aa005-3314-4753-a4de-c83a7ac65a80",a._sentryDebugIdIdentifier="sentry-dbid-923aa005-3314-4753-a4de-c83a7ac65a80")}catch{}})();const i=o({__name:"ContentLayout",props:{fullWidth:{type:Boolean},noPadding:{type:Boolean}},setup(a){return(e,n)=>(d(),s("div",{class:t(["content-layout",{"no-padding":e.noPadding}])},[l("div",{class:t(["centered-layout",{"full-width":e.fullWidth}])},[r(e.$slots,"default",{},void 0,!0)],2)],2))}});const _=c(i,[["__scopeId","data-v-fb4d67f9"]]);export{_ as C};
//# sourceMappingURL=ContentLayout.8cfadb43.js.map
