import"./jwt-decode.esm.b9bb33e7.js";(function(){try{var d=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(d._sentryDebugIds=d._sentryDebugIds||{},d._sentryDebugIds[e]="d5f5a8f0-2671-4593-b7bc-d83d900d05d0",d._sentryDebugIdIdentifier="sentry-dbid-d5f5a8f0-2671-4593-b7bc-d83d900d05d0")}catch{}})();const f=(...d)=>window.fetch(...d);export{f as l};
//# sourceMappingURL=fetch.7b0def40.js.map
