import{d as o,o as a,ac as s,f as d,u as _,S as r,_ as c}from"./jwt-decode.esm.b9bb33e7.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="39f93ca4-281f-4753-99b7-5e645c91dd40",e._sentryDebugIdIdentifier="sentry-dbid-39f93ca4-281f-4753-99b7-5e645c91dd40")}catch{}})();const i={class:"centered"},f=o({__name:"LoadingContainer",setup(e){return(n,t)=>(a(),s("div",i,[d(_(r))]))}});const u=c(f,[["__scopeId","data-v-52e6209a"]]);export{u as L};
//# sourceMappingURL=LoadingContainer.6b2e55a8.js.map
