import{L as n}from"./Logo.c4ca8242.js";import{d as r,o as a,a as d,u as f}from"./jwt-decode.esm.b9bb33e7.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="fb42139e-86fb-4678-9e8c-32d26f6659cb",e._sentryDebugIdIdentifier="sentry-dbid-fb42139e-86fb-4678-9e8c-32d26f6659cb")}catch{}})();const i="/assets/logo.0faadfa2.svg",u=r({__name:"AbstraLogo",props:{hideText:{type:Boolean},size:{}},setup(e){return(s,t)=>{var o;return a(),d(n,{"image-url":f(i),"brand-name":"Abstra","hide-text":s.hideText,size:(o=s.size)!=null?o:"small"},null,8,["image-url","hide-text","size"])}}});export{u as _};
//# sourceMappingURL=AbstraLogo.vue_vue_type_script_setup_true_lang.8204f8e4.js.map
