import{_ as l}from"./Login.vue_vue_type_script_setup_true_lang.f1a48ab2.js";import{d as f,ec as m,ei as g,ac as y,f as b,u as n,o as w,_ as k}from"./jwt-decode.esm.b9bb33e7.js";import{u as h}from"./workspaceStore.583d9afd.js";import"./CircularLoading.a4bd5a70.js";import"./Logo.c4ca8242.js";import"./string.04644599.js";import"./index.cfbca287.js";import"./userStore.3a2d2697.js";import"./url.7fa35693.js";import"./colorHelpers.53158244.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="c652db37-d2bc-4c5a-9d7c-9fc497174f49",e._sentryDebugIdIdentifier="sentry-dbid-c652db37-d2bc-4c5a-9d7c-9fc497174f49")}catch{}})();const v={class:"runner"},I=f({__name:"Login",setup(e){const o=m(),t=g(),r=h(),_=async()=>{const{redirect:a,...s}=t.query;if(a){await o.push({path:a,query:s,params:t.params});return}o.push({name:"playerHome",query:s})};return(a,s)=>{var c,d,p,u,i;return w(),y("div",v,[b(l,{"logo-url":(d=(c=n(r).state.workspace)==null?void 0:c.logoUrl)!=null?d:void 0,"brand-name":(p=n(r).state.workspace)==null?void 0:p.brandName,locale:(i=(u=n(r).state.workspace)==null?void 0:u.language)!=null?i:"en",onDone:_},null,8,["logo-url","brand-name","locale"])])}}});const H=k(I,[["__scopeId","data-v-12c690e1"]]);export{H as default};
//# sourceMappingURL=Login.53d97380.js.map
