import{O as s}from"./OmniChat.00da5ca5.js";import{u as a}from"./omniChatStore.c81c7dd1.js";import{d as i,ei as c,u as t,o as d,a as u,h as l}from"./jwt-decode.esm.b9bb33e7.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[r]="4db0040a-672e-481b-a25b-bf27b7e8eb0a",e._sentryDebugIdIdentifier="sentry-dbid-4db0040a-672e-481b-a25b-bf27b7e8eb0a")}catch{}})();const _=i({__name:"ConsoleOmniChat",setup(e){const n=c().params.projectId,o=a();return o.init("console",n),(p,b)=>t(o).controller&&t(o).repository?(d(),u(s,{key:0,"ai-chat-repository":t(o).repository,controller:t(o).controller,environment:{origin:"console",projectId:t(n)},"show-console-suggestions":!0},null,8,["ai-chat-repository","controller","environment"])):l("",!0)}});export{_};
//# sourceMappingURL=ConsoleOmniChat.vue_vue_type_script_setup_true_lang.b3c015f9.js.map
