import{W as s,dQ as d,dR as i}from"./jwt-decode.esm.b9bb33e7.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},c=new Error().stack;c&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[c]="a3980731-268a-4d65-bc09-4f24bd51c153",e._sentryDebugIdIdentifier="sentry-dbid-a3980731-268a-4d65-bc09-4f24bd51c153")}catch{}})();const{DatePicker:n,WeekPicker:t,MonthPicker:r,YearPicker:f,TimePicker:m,QuarterPicker:a,RangePicker:o}=d(i),u=s(n,{WeekPicker:t,MonthPicker:r,YearPicker:f,RangePicker:o,TimePicker:m,QuarterPicker:a,install:e=>(e.component(n.name,n),e.component(o.name,o),e.component(r.name,r),e.component(t.name,t),e.component(a.name,a),e)});export{u as D,r as M,a as Q,o as R,t as W};
//# sourceMappingURL=dayjs.618c5367.js.map
