import{O as l}from"./workspaceStore.583d9afd.js";import{d as c,U as u,ac as f,f as o,b as n,u as a,o as _,g as r,t as s,i as d,A as b,df as p}from"./jwt-decode.esm.b9bb33e7.js";import"./userStore.3a2d2697.js";import"./url.7fa35693.js";import"./colorHelpers.53158244.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="d3b44cf7-6b48-4252-8bf7-28868482ea57",e._sentryDebugIdIdentifier="sentry-dbid-d3b44cf7-6b48-4252-8bf7-28868482ea57")}catch{}})();const v=c({__name:"OidcLogoutCallback",setup(e){return u(async()=>{await new l().logoutCallback()}),(t,i)=>(_(),f("div",null,[o(a(b),null,{default:n(()=>[r(s(a(d).translate("i18n_oidclogoutcallback_authenticated_title")),1)]),_:1}),o(a(p),null,{default:n(()=>[r(s(a(d).translate("i18n_oidclogoutcallback_close_window_message")),1)]),_:1})]))}});export{v as default};
//# sourceMappingURL=OidcLogoutCallback.a60b6160.js.map
