import{P as f}from"./PlayerNavbar.53f81c7f.js";import{d as g,ec as h,ei as c,r as b,c as y,j as k,ac as v,u as n,a as w,h as L,e as C,f as I,o as i,_ as N}from"./jwt-decode.esm.b9bb33e7.js";import{u as V}from"./workspaceStore.583d9afd.js";import"./userStore.3a2d2697.js";import"./metadata.17375f25.js";import"./PhWebhooksLogo.vue.a73cf99c.js";import"./LoadingOutlined.bcf2a831.js";import"./PhSignOut.vue.1cca1af4.js";import"./index.6a5e28c0.js";import"./url.7fa35693.js";import"./colorHelpers.53158244.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[e]="aab9c681-b768-4c9e-bc71-56428adbdf0f",o._sentryDebugIdIdentifier="sentry-dbid-aab9c681-b768-4c9e-bc71-56428adbdf0f")}catch{}})();const x={class:"main-container"},B={class:"content"},D=g({__name:"Main",setup(o){const e=h(),t=V(),d=c().path,a=b(null),u=async({path:s,id:r})=>{a.value=r,await e.push({path:`/${s}`}),a.value=null},l=()=>{e.push({name:"playerLogin"})},p=()=>{e.push({name:"playerLogin"})},_=y(()=>!!c().meta.hideLogin);return(s,r)=>{const m=k("RouterView");return i(),v("div",x,[n(t).state.workspace?(i(),w(f,{key:0,"current-path":n(d),"hide-login":_.value,"runner-data":n(t).state.workspace,loading:a.value,onNavigate:u,onLoginClick:p,onLogoutClick:l},null,8,["current-path","hide-login","runner-data","loading"])):L("",!0),C("section",B,[I(m)])])}}});const F=N(D,[["__scopeId","data-v-f095bece"]]);export{F as default};
//# sourceMappingURL=Main.b3e5d5fe.js.map
