import{C as n,D as r,E as o,F as d,P as c,G as p,H as f,I as m,J as a,K as u,L as g,N as b,O as l}from"./jwt-decode.esm.b9bb33e7.js";import{a as y,b as i}from"./router.d8fe262e.js";import{s as w}from"./workspaceStore.583d9afd.js";import{_ as h}from"./App.vue_vue_type_style_index_0_lang.35b9297a.js";import"./userStore.3a2d2697.js";import"./url.7fa35693.js";import"./colorHelpers.53158244.js";import"./PlayerConfigProvider.8a1d38e8.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[s]="8a6d76c1-4e74-4dfc-9341-dfd77029eb27",t._sentryDebugIdIdentifier="sentry-dbid-8a6d76c1-4e74-4dfc-9341-dfd77029eb27")}catch{}})();class I{static init(){setInterval(()=>{fetch("/_healthcheck").catch(()=>{})},20*1e3)}}(async()=>{await w();const t=await y(),s=n(),e=r({render:()=>u(h)});o.init(),d(e,i,t),I.init(),e.use(i),e.use(s),e.use(c),e.mount("#app"),e.component("VSelect",p),e.component("Markdown",f),e.component("Message",m),a(e,g),a(e,b),a(e,l)})();
//# sourceMappingURL=player.4ba2218c.js.map
