import{_ as f}from"./AbstraLogo.vue_vue_type_script_setup_true_lang.8204f8e4.js";import{B as m}from"./BaseLayout.31267389.js";import{d as l,al as y,c8 as v,_ as u,b4 as g,b5 as b,o as _,ac as h,e as a,ad as n,ei as w,ec as S,U as L,a as k,b as s,f as i,u as x}from"./jwt-decode.esm.b9bb33e7.js";import{u as B}from"./editor.64e4d209.js";import{A as I}from"./index.88a43c5d.js";import"./Logo.c4ca8242.js";import"./router.d8fe262e.js";import"./workspaceStore.583d9afd.js";import"./userStore.3a2d2697.js";import"./url.7fa35693.js";import"./colorHelpers.53158244.js";import"./useCodebaseEvents.fd37c61f.js";import"./contracts.generated.0a04f0c8.js";import"./index.cb46e99b.js";import"./constants.0deee127.js";import"./linters.f033aedb.js";import"./asyncComputed.7ddee0b0.js";import"./Breadcrumb.bc48ca6d.js";import"./index.6a5e28c0.js";import"./index.b57ea477.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="5474a7af-e23c-4699-900f-a453235b054f",e._sentryDebugIdIdentifier="sentry-dbid-5474a7af-e23c-4699-900f-a453235b054f")}catch{}})();const $=l({props:{loading:{type:Boolean,default:!0},color:{type:String,default:"#ea576a"},size:{type:String,default:"10px"},radius:{type:String,default:"100%"}},setup(e){const o=y({spinnerStyle:{width:e.size,height:e.size,borderRadius:e.radius,backgroundColor:e.color}});return{...v(o)}}});const P={class:"v-spinner"};function D(e,o,r,d,c,p){return g((_(),h("div",P,[a("div",{class:"v-beat v-beat-odd",style:n(e.spinnerStyle)},null,4),a("div",{class:"v-beat v-beat-even",style:n(e.spinnerStyle)},null,4),a("div",{class:"v-beat v-beat-odd",style:n(e.spinnerStyle)},null,4)],512)),[[b,e.loading]])}const R=u($,[["render",D],["__scopeId","data-v-06538001"]]),j={class:"content"},z=l({__name:"ProjectLogin",setup(e){const o=w(),r=S(),d=B();function c(){const t=new URL(location.href);t.searchParams.delete("api-key"),r.replace(t.pathname+t.search)}function p(){const t=o.query["api-key"];if(typeof t=="string")return t}return L(async()=>{const t=p();if(!t){r.push({name:"error"});return}await d.createLogin(t).then(c),r.push({name:"editor"})}),(t,A)=>(_(),k(m,null,{navbar:s(()=>[i(x(I),{style:{padding:"5px 25px",border:"1px solid #f0f0f0"}},{title:s(()=>[i(f)]),_:1})]),content:s(()=>[a("div",j,[i(R)])]),_:1}))}});const te=u(z,[["__scopeId","data-v-d2a19803"]]);export{te as default};
//# sourceMappingURL=ProjectLogin.972cff72.js.map
