import{_ as i,C as n}from"./View.vue_vue_type_script_setup_true_lang.8892f80d.js";import{d as p,ei as s,a as m,u as c,o as a}from"./jwt-decode.esm.b9bb33e7.js";import"./router.135b49e3.js";import"./index.cb46e99b.js";import"./fetch.7b0def40.js";import"./record.c01e7f08.js";import"./SaveButton.8e4a5fbe.js";import"./ExclamationCircleOutlined.40ff37b4.js";import"./CrudView.f8f7347d.js";import"./DocsButton.vue_vue_type_script_setup_true_lang.264a92d9.js";import"./constants.0deee127.js";import"./url.7fa35693.js";import"./PhDotsThreeVertical.vue.e9b1faec.js";import"./index.b57ea477.js";import"./asyncComputed.7ddee0b0.js";import"./omniChatStore.c81c7dd1.js";import"./uuid.40423699.js";import"./PhCopySimple.vue.df39762b.js";import"./PhPencil.vue.ea9f0def.js";import"./useCodebaseEvents.fd37c61f.js";import"./contracts.generated.0a04f0c8.js";import"./index.cfbca287.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[r]="567c7c2c-0bd2-4f54-8c35-727874ad81c1",o._sentryDebugIdIdentifier="sentry-dbid-567c7c2c-0bd2-4f54-8c35-727874ad81c1")}catch{}})();const A=p({__name:"EnvVars",setup(o){const t=s().params.projectId,e=new n(t);return(d,f)=>(a(),m(i,{"env-var-repository":c(e),mode:"console"},null,8,["env-var-repository"]))}});export{A as default};
//# sourceMappingURL=EnvVars.8f5b7bdb.js.map
