import{O as l}from"./workspaceStore.583d9afd.js";import{d as c,U as f,ac as u,f as n,b as d,u as a,o as _,g as o,t as r,i,A as b,df as p}from"./jwt-decode.esm.b9bb33e7.js";import"./userStore.3a2d2697.js";import"./url.7fa35693.js";import"./colorHelpers.53158244.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="9eadbde8-4d82-4af9-b26b-df459e5deedf",e._sentryDebugIdIdentifier="sentry-dbid-9eadbde8-4d82-4af9-b26b-df459e5deedf")}catch{}})();const v=c({__name:"OidcLoginCallback",setup(e){return f(async()=>{await new l().loginCallback()}),(t,s)=>(_(),u("div",null,[n(a(b),null,{default:d(()=>[o(r(a(i).translate("i18n_oidclogincallback_authenticated_title")),1)]),_:1}),n(a(p),null,{default:d(()=>[o(r(a(i).translate("i18n_oidclogincallback_close_window_message")),1)]),_:1})]))}});export{v as default};
//# sourceMappingURL=OidcLoginCallback.9dd86a22.js.map
