import{d as c,eF as i,c as r,o,ac as t,h as d,eh as _,t as p,_ as u}from"./jwt-decode.esm.b9bb33e7.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="ae592d79-a649-4321-aba8-37c20205e99c",e._sentryDebugIdIdentifier="sentry-dbid-ae592d79-a649-4321-aba8-37c20205e99c")}catch{}})();const g={class:"logo"},m=["src","alt"],f=c({__name:"Logo",props:{imageUrl:{},brandName:{},hideText:{type:Boolean},size:{}},setup(e){const a=e;i(s=>({"4521d904":n.value}));const n=r(()=>a.size==="small"?"24px":a.size==="large"?"80px":"50px"),l=r(()=>`${a.brandName} Logo`);return(s,y)=>(o(),t("div",g,[s.imageUrl?(o(),t("img",{key:0,class:"logo-img",src:s.imageUrl,alt:l.value},null,8,m)):d("",!0),s.hideText?d("",!0):(o(),t("span",{key:1,class:_(s.size)},p(s.brandName),3))]))}});const h=u(f,[["__scopeId","data-v-8f34aac0"]]);export{h as L};
//# sourceMappingURL=Logo.c4ca8242.js.map
